@@ -89,7 +89,7 @@ class RteIE(RteBaseIE):
             'id': '10478715',
             'ext': 'mp4',
             'title': 'iWitness',
-            'thumbnail': 're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*\.jpg$',
             'description': 'The spirit of Ireland, one voice and one minute at a time.',
             'duration': 60.046,
             'upload_date': '20151012',
@@ -116,7 +116,7 @@ class RteRadioIE(RteBaseIE):
             'id': '10507902',
             'ext': 'mp4',
             'title': 'Gloria',
-            'thumbnail': 're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*\.jpg$',
             'description': 'md5:9ce124a7fb41559ec68f06387cabddf0',
             'timestamp': 1451203200,
             'upload_date': '20151227',
@@ -129,7 +129,7 @@ class RteRadioIE(RteBaseIE):
             'id': '3250678',
             'ext': 'flv',
             'title': 'The Lyric Concert with Paul Herriott',
-            'thumbnail': 're:^https?://.*\.jpg$',
+            'thumbnail': r're:^https?://.*\.jpg$',
             'description': '',
             'timestamp': 1333742400,
             'upload_date': '20120406',
